Python: module mx2.types

mx2.types | index /Users/vpaeder/Projects/pymx2/mx2/types.py

`Data types for MX2 driver.`

Classes
`` |  | builtins.object CoilValue RegisterValue
class CoilValue(builtins.object)
`` | `CoilValue(coil: mx2.enums.Coil, value: bool) A container class used to hold a value together with an associated coil. Attributes: coil(Coil): coil. value(bool): coil state.`
| Methods defined here: __eq__(self, other) -> bool `Return self==value.` __init__(self, coil: mx2.enums.Coil, value: bool) `Initialize self. See help(type(self)) for accurate signature.` __neq__(self, other) -> bool __repr__(self) -> str `Return repr(self).` is_(self, other) -> bool is_not(self, other) -> bool Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: __hash__ = None
class RegisterValue(builtins.object)
`` | `RegisterValue(register: mx2.enums.Register, value: int) A container class used to hold a value together with an associated register. Attributes: register(Register): register. value(int): register value.`
| Methods defined here: __add__(self, other) -> int __and__(self, other) -> int __eq__(self, other) -> bool `Return self==value.` __floordiv__(self, other) -> int __format__(self, spec: str) -> str `Default object formatter.` __ge__(self, other) -> bool `Return self>=value.` __gt__(self, other) -> bool `Return self>value.` __iadd__(self, other) -> 'RegisterValue' __iand__(self, other) -> 'RegisterValue' __ifloordiv__(self, other) -> 'RegisterValue' __ilshift__(self, amount) -> 'RegisterValue' __imod__(self, other) -> 'RegisterValue' __imul__(self, other) -> 'RegisterValue' __index__(self) -> int __init__(self, register: mx2.enums.Register, value: int) `Initialize self. See help(type(self)) for accurate signature.` __inv__(self) -> int __ior__(self, other) -> 'RegisterValue' __ipow__(self, other) -> 'RegisterValue' __irshift__(self, amount) -> 'RegisterValue' __isub__(self, other) -> 'RegisterValue' __ixor__(self, other) -> 'RegisterValue' __le__(self, other) -> bool `Return self<=value.` __lshift__(self, amount: int) -> int __lt__(self, other) -> bool `Return self<value.` __mod__(self, other) -> int __mul__(self, other) -> int __neg__(self) -> int __neq__(self, other) -> bool __not__(self) -> int __or__(self, other) -> int `Return self|value.` __pow__(self, other) -> int __repr__(self) -> str `Return repr(self).` __rshift__(self, amount: int) -> int __sub__(self, other) -> int __xor__(self, other) -> int is_(self, other) -> bool is_not(self, other) -> bool to_bytes(self, n_bytes: int, endianness: str) -> bytes Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: __hash__ = None

Data
`` |  | __all__ = ['CoilValue', 'RegisterValue']